<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=co
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'Corsu [co]',
	'0_liste' => 'spip-dev@rezo.net',
	'0_mainteneur' => 'spip-dev@rezo.net',

	// A
	'access_interface_graphique' => 'Ritornu à l’interfaccia gràfica sana',
	'access_mode_texte' => 'Fà cumparisce l’interfaccia testu simplificata',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Mudificà st’artìculu',
	'admin_modifier_auteur' => 'Mudificà st’autore',
	'admin_modifier_breve' => 'Mudificà stu dispacciu',
	'admin_modifier_mot' => 'Mudificà stu segnu',
	'admin_modifier_rubrique' => 'Mudificà sta rùbbrica',
	'admin_recalculer' => 'Ricaricà sta pàgina',
	'afficher_calendrier' => 'Mustrà l’almanaccu',
	'afficher_trad' => 'fà cumparisce e traduzzioni',
	'alerte_maj_impossible' => '<b>Attenti !</b> Ùn hè pussìbule l’aghjurnamentu di a basa SQL versu a versione @version@, 
	forse per via d’un prublemu cù i dirittu di mudìficazione in a basa di dati. Cuntattate puru u vostru òspite.',
	'alerte_modif_info_concourante' => 'ATTENTI : St’infurmazione hè stata mudificata in listessu mentre. U valore attuale hè :',
	'analyse_xml' => 'Anàlisi XML',
	'annuler' => 'Annullà',
	'antispam_champ_vide' => 'Lasciate puru stu campu viotu :',
	'articles_recents' => 'L’ùltimi artìculi',
	'avis_archive_incorrect' => 'u schedariu d’archiviu ùn hè micca un schedariu SPIP',
	'avis_archive_invalide' => 'u schedariu d’archiviu ùn hè micca vàlidu',
	'avis_attention' => 'ATTENTI !',
	'avis_champ_incorrect_type_objet' => 'Nome di campu sbagliatu @name@ per oggettu di tippu @type@',
	'avis_colonne_inexistante' => 'A culonna @col@ ùn esiste micca',
	'avis_erreur' => 'Errore: vede quì sottu',
	'avis_erreur_connexion' => 'Errore di cunnessione',
	'avis_erreur_cookie' => 'problemu di cookie',
	'avis_erreur_fonction_contexte' => 'Errore di prugramazione. Ùn deve esse chjamata sta funzione in tale cuntestu.',
	'avis_erreur_mysql' => 'Errore SQL',
	'avis_erreur_sauvegarde' => 'Errore durante u salvamentu (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Problemu d’accessu à u spaziu privatu',

	// B
	'barre_a_accent_grave' => 'Inserisce un A maiùsculu cù l’aletta à falà',
	'barre_aide' => 'Aduprate puru l’accurtatoghji tipugràfichi pè arricchisce a paginatura',
	'barre_e_accent_aigu' => 'Inserisce un E maiùsculu cù l’aletta à cullà',
	'barre_eo' => 'Inserisce un E in l’O',
	'barre_eo_maj' => 'Inserisce un E in l’O maiùsculu',
	'barre_euro' => 'Inserisce u sìmbulu €',
	'barre_gras' => 'Mette in {{grassu}}',
	'barre_guillemets' => 'Mette trà « virgulette »',
	'barre_guillemets_simples' => 'Mette trà “virgulette altre”',
	'barre_intertitre' => 'Scambià in {{{infratìtulu}}}',
	'barre_italic' => 'Mette in {itàlicu}',
	'barre_lien' => 'Scambià in [lea ipertestu->http://...]',
	'barre_lien_input' => 'Rinsignate puru l’indirizzu di a vostra lea (pudete dà un indirizzu web di forma http://www.umositu.com o 
	indettate solu u nùmeru d’un artìculu di stu situ.',
	'barre_note' => 'Scambià in [[Nota di fondu di pàgina]]',
	'barre_paragraphe' => 'Creà un paragrafu',
	'barre_quote' => '<quote>Cità un messagiu</quote>',
	'bouton_changer' => 'Scambià',
	'bouton_chercher' => 'Circà',
	'bouton_choisir' => 'Sceglie',
	'bouton_deplacer' => 'Move',
	'bouton_download' => 'Scaricà', # MODIF
	'bouton_enregistrer' => 'Arregistrà',
	'bouton_radio_desactiver_messagerie_interne' => 'Disattivà a mesageria interna',
	'bouton_radio_envoi_annonces' => 'Mandà l’annunci edituriali',
	'bouton_radio_non_envoi_annonces' => 'Ùn mandà micca annunci',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Ùn mandà micca a lista di a nuvità',
	'bouton_recharger_page' => 'ricaricà sta pàgina',
	'bouton_telecharger' => 'Scaricà',
	'bouton_upload' => 'Scaricà', # MODIF
	'bouton_valider' => 'Cunvalidà',

	// C
	'cal_apresmidi' => 'dopu meziornu',
	'cal_jour_entier' => 'ghjornu sanu',
	'cal_matin' => 'à mane',
	'cal_par_jour' => 'almanaccu pè ghjornu',
	'cal_par_mois' => 'almanaccu pè mese',
	'cal_par_semaine' => 'almanaccu pè settimana',
	'choix_couleur_interface' => 'culore ',
	'choix_interface' => 'scelta di l’interfaccia',
	'colonne' => 'Culonna',
	'confirm_changer_statut' => 'Attenti, avete dumandate di scambià u statu di st’elementu. Vulete cuntinuà ?',
	'correcte' => 'curretta', # chaine utilisée dans le debugueur : "validation .. impossible" ou "validation .. correcte"

	// D
	'date_aujourdhui' => 'oghje',
	'date_avant_jc' => 'nanzu Ghj.C.',
	'date_dans' => 'in @delai@',
	'date_de_mois_1' => '@j@ di @nommois@',
	'date_de_mois_10' => '@j@ d’@nommois@',
	'date_de_mois_11' => '@j@ di @nommois@',
	'date_de_mois_12' => '@j@ di @nommois@',
	'date_de_mois_2' => '@j@ di @nommois@',
	'date_de_mois_3' => '@j@ di @nommois@',
	'date_de_mois_4' => '@j@ d’@nommois@',
	'date_de_mois_5' => '@j@ di @nommois@',
	'date_de_mois_6' => '@j@ di @nommois@',
	'date_de_mois_7' => '@j@ di @nommois@',
	'date_de_mois_8' => '@j@ d’@nommois@',
	'date_de_mois_9' => '@j@ di @nommois@',
	'date_demain' => 'dumane',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ à @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ de @heure_debut@ a @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ da @heure_debut@@dtabbr@ a @dtstart@@heure_fin@@dtend@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ di u @annee@',
	'date_fmt_mois_annee' => '@nommois@ di u @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'u @nomjour@ @date@',
	'date_fmt_periode' => 'Da u @date_debut@ à u @date_fin@',
	'date_fmt_periode_abbr' => 'Da u @dtart@@date_debut@@dtabbr@ à u @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Da u',
	'date_fmt_periode_to' => 'à u',
	'date_heures' => 'ore',
	'date_hier' => 'eri',
	'date_il_y_a' => '@delai@ fà',
	'date_jnum1' => '1u',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'dumènica',
	'date_jour_1_abbr' => 'dum.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'luni',
	'date_jour_2_abbr' => 'lun.',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => 'marti',
	'date_jour_3_abbr' => 'mar.',
	'date_jour_3_initiale' => 'm.',
	'date_jour_4' => 'mèrcuri',
	'date_jour_4_abbr' => 'mer.',
	'date_jour_4_initiale' => 'm.',
	'date_jour_5' => 'ghjovi',
	'date_jour_5_abbr' => 'ghj.',
	'date_jour_5_initiale' => 'j.',
	'date_jour_6' => 'vènneri',
	'date_jour_6_abbr' => 'ven.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'sàbatu',
	'date_jour_7_abbr' => 'sab.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'ghjorni',
	'date_minutes' => 'minuti',
	'date_mois' => 'mese',
	'date_mois_1' => 'ghjennaghju',
	'date_mois_10' => 'ottobre',
	'date_mois_10_abbr' => 'ott.',
	'date_mois_11' => 'nuvembre',
	'date_mois_11_abbr' => 'nuv.',
	'date_mois_12' => 'dicembre',
	'date_mois_12_abbr' => 'dic.',
	'date_mois_1_abbr' => 'ghjen.',
	'date_mois_2' => 'ferraghju',
	'date_mois_2_abbr' => 'ferr.',
	'date_mois_3' => 'marzu',
	'date_mois_3_abbr' => 'mar.',
	'date_mois_4' => 'aprile',
	'date_mois_4_abbr' => 'apr.',
	'date_mois_5' => 'maghju',
	'date_mois_5_abbr' => 'mag.',
	'date_mois_6' => 'ghjugnu',
	'date_mois_6_abbr' => 'ghju.',
	'date_mois_7' => 'lugliu',
	'date_mois_7_abbr' => 'lug.',
	'date_mois_8' => 'aostu',
	'date_mois_8_abbr' => 'aos.',
	'date_mois_9' => 'settembre',
	'date_mois_9_abbr' => 'sett.',
	'date_saison_1' => 'inguernu',
	'date_saison_2' => 'veranu',
	'date_saison_3' => 'estate',
	'date_saison_4' => 'auturnu',
	'date_secondes' => 'seconde',
	'date_semaines' => 'settimane',
	'date_un_mois' => 'mese',
	'date_une_heure' => 'ora',
	'date_une_minute' => 'minutu',
	'date_une_seconde' => 'seconda',
	'date_une_semaine' => 'settimana',
	'dirs_commencer' => ' di modu à principià veramente a stallazione',
	'dirs_preliminaire' => 'Prima di tuttu : <b>Scioglie i diritti d’accessu</b>',
	'dirs_probleme_droits' => 'Problemu di diritti d’accessu',
	'dirs_repertoires_absents' => '<p><b>I seguenti cartulari ùn sò micca stati trovi :</b></p><ul>@bad_dirs@</ul>
	<p>Pò esse quessa cagiunata da un prublemu di gattiva messa in forma di lèttere maiùscule o minùscule.
	Verificate puru chì e minùscule è maiùscule di sti cartulari s’accordanu cù ciò chì cumparisce quì sopra;
	s’ella ùn hè cusì, rinumate i cartulari cù u vostru cliente FTP di modu à curregge u sbagliu.</p>
	<p>Fatta quessa, puderete ',
	'dirs_repertoires_suivants' => '<p><b>I seguenti cartulari ùn sò micca accessìbuli in scrittura :</b></p> <ul>@bad_dirs@</ul>
	<p>Pè curregge la, dauprate puru u vostru cliente FTP pè scioglie i diritti d’accessu à ognunu di sti cartulari.
	A prucedura hè spiegata in ditagliu in a guida di stallazione.</p>
	<p>Fatta quessa, puderete ',
	'double_occurrence' => 'In doppiu',

	// E
	'en_cours' => 'in corsu',
	'envoi_via_le_site' => 'Invià à traversu u situ',
	'erreur' => 'Errore',
	'erreur_balise_non_fermee' => 'ùltima balisa micca chjosa :',
	'erreur_technique_enregistrement_champs' => 'Per via d’un errore tècnicu, u campu @champs@ ùn hè micca statu arregistratu.',
	'erreur_technique_enregistrement_impossible' => 'Per via d’un errore tècnicu, l’arregistramentu ùn hè micca statu fattu.',
	'erreur_texte' => 'errore/i',
	'etape' => 'Tappa',

	// F
	'fichier_introuvable' => 'Schedariu @fichier@ inesistente',
	'form_auteur_confirmation' => 'Cunfirmate l’indirizzu mail',
	'form_auteur_email_modifie' => 'Hè statu mudificatu u vostru indirizzu mail.',
	'form_deja_inscrit' => 'Site digià iscrittu.',
	'form_email_non_valide' => 'Ùn hè vàlidu u vostru indirizzu email.',
	'form_forum_access_refuse' => 'Ùn avete più accessu à stu situ.',
	'form_forum_bonjour' => 'Bonghjornu, o @nom@,',
	'form_forum_email_deja_enregistre' => 'St’indirizzu email hè digià arregistratu, pudete puru usà u vostru password abbituale.',
	'form_forum_identifiant_mail' => 'U vostru nuvellu còdice vi hè statu mandatu avà per email.',
	'form_forum_identifiants' => 'Còdici persunali',
	'form_forum_indiquer_nom_email' => 'Rinsignate quì u vostru nome è u vostru indirizzu email. Da quì à pocu vi ghjunghjerà u vostru còdice persunale, per email.',
	'form_forum_login' => 'login :',
	'form_forum_message_auto' => '(què hè un messagiu autumàticu)',
	'form_forum_pass' => 'password :',
	'form_forum_probleme_mail' => 'Problemu di mail : Ùn pò micca esse mandatu u còdice.',
	'form_forum_voici1' => 'Eccu i vostri còdici da pudè participà à a vita di u situ "@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'Eccu i vostri còdici da pudè prupone artìculi nant’à u situ "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'Rinsignate puru u vostru indirizzu email.',
	'form_indiquer_nom' => 'Rinsignate puru u vostru nome.',
	'form_indiquer_nom_site' => 'Rinsignate puru u nome di u vostru situ.',
	'form_pet_deja_enregistre' => 'Hè digià arregistratu stu situ',
	'form_pet_signature_pasprise' => 'Ùn hè stata pigliata in contu a vostra zifra.',
	'form_prop_confirmer_envoi' => 'Cunfirmate l’inviu',
	'form_prop_description' => 'Discrizzione/Cummentu',
	'form_prop_enregistre' => 'Hè stata arregistrata a vostra pruposta. Cumpariscerà in ligna dopu cunvalidazione da i respunsèvuli di stu situ.',
	'form_prop_envoyer' => 'Mandà un messagiu',
	'form_prop_indiquer_email' => 'Rinsignate puru un indirizzu email vàlidu',
	'form_prop_indiquer_nom_site' => 'Date u nome di u situ.',
	'form_prop_indiquer_sujet' => 'Date puru un sugettu',
	'form_prop_message_envoye' => 'Messagiu mandatu',
	'form_prop_non_enregistre' => 'Ùn hè micca stata arregistrata a vostra pruposta.',
	'form_prop_sujet' => 'Sugettu',
	'form_prop_url_site' => 'Indirizzu (URL) di u situ', # MODIF
	'forum_non_inscrit' => 'Ùn site micca iscrittu, o l’indirizzu o u password sò sbagliati.',
	'forum_par_auteur' => 'da @auteur@',
	'forum_titre_erreur' => 'Errore ...',

	// I
	'ical_texte_rss_articles' => 'U schedariu «backend» di l’artìculi di stu situ si trova à l’indirizzu :',
	'ical_texte_rss_articles2' => 'Pudete dinò ottene schedari «backend» pè l’artìculi d’ogni rùbbrica di u situ :',
	'ical_texte_rss_breves' => 'Esiste dinò un schedariu chì cuntene i dispacci di u situ. Indettendu un nùmeru di rùbbrica, ottenerete solu i dispacci
		di sta rùbbrica.',
	'icone_a_suivre' => 'Cuntrollu',
	'icone_admin_site' => 'Amministrazione di u situ',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Aiutu',
	'icone_articles' => 'Artìculi',
	'icone_auteurs' => 'Autori',
	'icone_brouteur' => 'Navigazione veloce',
	'icone_configuration_site' => 'Paràmetri',
	'icone_configurer_site' => 'Cunfigurà u vostru situ',
	'icone_creer_nouvel_auteur' => 'Creà un nuvellu autore',
	'icone_creer_rubrique' => 'Creà una rùbbrica',
	'icone_creer_sous_rubrique' => 'Creà una sotturùbbrica',
	'icone_deconnecter' => 'Scunnette si',
	'icone_discussions' => 'Ragiunate',
	'icone_doc_rubrique' => 'Ducumenti di e rùbbriche',
	'icone_ecrire_article' => 'Scrive un nuvellu artìculu',
	'icone_edition_site' => 'Scrittura',
	'icone_gestion_langues' => 'Gestione di e lingue',
	'icone_informations_personnelles' => 'Infurmazioni persunale',
	'icone_interface_complet' => 'interfaccia sana',
	'icone_interface_simple' => 'Interfaccia simplificata',
	'icone_maintenance_site' => 'Mantenimentu di u situ',
	'icone_messagerie_personnelle' => 'Messageria persunale',
	'icone_repartition_debut' => 'Vede u spartimentu da u principiu',
	'icone_rubriques' => 'Rùbbriche',
	'icone_sauver_site' => 'Fà un salvamentu di u situ',
	'icone_site_entier' => 'U situ sanu',
	'icone_sites_references' => 'Siti riferiti',
	'icone_statistiques' => 'Statìstiche di u situ',
	'icone_suivi_activite' => 'Seguità a vita di u situ',
	'icone_suivi_actualite' => 'Evuluzione di u situ',
	'icone_suivi_pettions' => 'Seguità/gestisce e petizioni',
	'icone_suivi_revisions' => 'Mudìfiche di l’artìculi',
	'icone_supprimer_document' => 'Sguassà stu ducumentu',
	'icone_supprimer_image' => 'Sguassà st’imàgine',
	'icone_tous_articles' => 'Tutti i vostri artìculi',
	'icone_tous_auteur' => 'Tutti l’autori',
	'icone_tous_visiteur' => 'Tutti i visitori',
	'icone_visiter_site' => 'Situ pùbblicu', # MODIF
	'icone_voir_en_ligne' => 'Vede in ligna',
	'img_indisponible' => 'imàgine micca dispunìbule',
	'impossible' => 'impussìbule',
	'info_a_suivre' => 'À SUIVRE »',
	'info_acces_interdit' => 'Accessu interdettu',
	'info_acces_refuse' => 'Accessu rifiutatu',
	'info_action' => 'Azzione : @action@',
	'info_administrer_rubriques' => 'Pudete puru amministrà sta rùbbrica cù e so sotturùbbriche',
	'info_adresse_non_indiquee' => 'ùn avete rinsignatu nisun indirizzu da pruvà !',
	'info_aide' => 'AIUTU :',
	'info_ajouter_mot' => 'Aghjunghje sta parulla',
	'info_annonce' => 'ANNUNCIU',
	'info_annonces_generales' => 'Annunci generali :',
	'info_article_propose' => 'Artìculu prupostu',
	'info_article_publie' => 'Artìculu pubblicatu',
	'info_article_redaction' => 'Artìculu in corsu di scrittura',
	'info_article_refuse' => 'Artìculu rifiutatu',
	'info_article_supprime' => 'Artìculu sguassatu',
	'info_articles' => 'Artìculi',
	'info_articles_a_valider' => 'L’artìculi da cunvalidà',
	'info_articles_nb' => '@nb@ artìculi',
	'info_articles_proposes' => 'Artìculi pruposti',
	'info_articles_un' => '1 artìculu',
	'info_auteurs_nombre' => 'autore/i :',
	'info_authentification_ftp' => 'Autentificazione (cù FTP).',
	'info_breves_2' => 'dispacci',
	'info_connexion_refusee' => 'Cunnessione rifiutata',
	'info_contact_developpeur' => 'Cuntattate puru un sviluppore.',
	'info_contenance' => 'Stu situ cuntene :',
	'info_contribution' => 'contributi di foru', # MODIF
	'info_copyright' => '@spip@ hè un prugrammu lìberu distribuitu @lien_gpl@.',
	'info_copyright_doc' => 'Per sapè ne di più, visitate puru u situ <a href=\'http://www.spip.net/fr\'>http://www.spip.net/fr</a>.', # MODIF
	'info_copyright_gpl' => 'sottu licenza GPL',
	'info_cours_edition' => 'I vostri artìculi in corsu di scrittura',
	'info_creer_repertoire' => 'Create puru un schedariu o un cartulare chjamatu :',
	'info_creer_repertoire_2' => 'à l’internu di u sottucartulare <b>@repertoire@</b>, poi :',
	'info_creer_vignette' => 'creazione autumàtica di a figuretta',
	'info_deplier' => 'Spalancà',
	'info_descriptif_nombre' => 'descrittivu/i :',
	'info_description' => 'Discrizzione :',
	'info_description_2' => 'Discrizzione :',
	'info_dimension' => 'Taglia :',
	'info_ecire_message_prive' => 'Scrive un messagiu privatu',
	'info_email_invalide' => 'Indirizzu email invàlida.',
	'info_en_cours_validation' => 'I vostri artìculi in corsu di scrittura',
	'info_en_ligne' => 'Attualmente in ligna :',
	'info_envoyer_message_prive' => 'Mandà un messagiu privatu à st’autore',
	'info_erreur_requete' => 'Errore in a richiesta :',
	'info_erreur_squelette2' => 'ùn hè dispunìbule nisun mudellu <b>@fichier@</b> ...',
	'info_erreur_systeme' => 'Errore sistema (errno @errsys@)',
	'info_erreur_systeme2' => 'Forse hè colmu u discu duru, o puru hè scundisata a basa di dati.<br />
<span style="color:red;">Pruvate puru di <a href=\'@script@\'>riparà a basa</a>, o cuntattate u vostru òspite.</span>',
	'info_fini' => 'Hè fatta !',
	'info_format_image' => 'Forme d’imàgini chì ponu esse usate da creà figurette : @gd_formats@.',
	'info_format_non_defini' => 'forma indefinita',
	'info_grand_ecran' => 'Screnu maiò',
	'info_image_aide' => 'AIUTU',
	'info_image_process_titre' => 'Mètudu di fàbbrica di e figurette',
	'info_impossible_lire_page' => '<b>Errore !</b> Impussìbule di leghje a pàgina <tt><html>@test_proxy@</html></tt> à traversu u proxy ',
	'info_installation_systeme_publication' => 'Stallazione di u sistema di pubblicazione ...',
	'info_installer_documents' => 'Pudete puru stallà in autumàticu tutti i ducumenti cuntenuti in u cartulare @upload@.',
	'info_installer_ftp' => 'Da amministratore, pudete stallà schedari (cù FTP) in u cartulare @upload@, da pudè li sceglie dopu direttamente da quì.',
	'info_installer_images' => 'Pudete puru stallà imàgini in furmatu JPEG, GIF è PNG.',
	'info_installer_images_dossier' => 'Stallà imàgini in u cartulare @upload@ da pudè li sceglie da quì.',
	'info_interface_complete' => 'interfaccia sana',
	'info_interface_simple' => 'Interfaccia simplificata',
	'info_joindre_document_article' => 'Pudete puru alleà à st’artìculu ducumenti di tippu',
	'info_joindre_document_rubrique' => 'Pudete puru aghjunghje in sta rùbbrica ducumenti di tippu',
	'info_joindre_documents_article' => 'Pudete puru alleà à u vostru artìculu ducumenti di tippu :',
	'info_l_article' => 'l’artìculu',
	'info_la_breve' => 'u dispacciu',
	'info_la_rubrique' => 'a rùbbrica',
	'info_langue_principale' => 'Lingua principale di u situ',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'da @les_auteurs@',
	'info_logo_format_interdit' => 'Sò auturizati solu i logos in furmatu @formats@.',
	'info_logo_max_poids' => 'I logos devenu per forza pisà di menu di @maxi@ (stu schedariu pesa @actuel@).',
	'info_mail_fournisseur' => 'voi@furnitore.com',
	'info_message_2' => 'MESSAGIU',
	'info_message_supprime' => 'MESSAGIU SGUASSATU',
	'info_messages_nb' => '@nb@ messagi',
	'info_messages_un' => '1 messagiu',
	'info_mise_en_ligne' => 'Data di messa in ligna :',
	'info_modification_parametres_securite' => 'mudificazione di i paràmetri di sicurezza',
	'info_mois_courant' => 'In stu mese :',
	'info_mot_cle_ajoute' => 'U segnu hè statu aghjuntu à',
	'info_multi_herit' => 'Lingua predefinita',
	'info_multi_langues_soulignees' => 'E <u>lingue sottufrisgiate</u> godenu d’una traduzzione di tutti i testi di l’interfaccia. 
		Sè vo sceglite ste lingue, seranu tradutti in autumàticu assai elementi di u situ pùbblicu (date, furmulari, ...). 
		Per e lingue micca sottufrisgiate, st’elementi cumparisceranu in a lingua principale di u situ.', # MODIF
	'info_multilinguisme' => 'Multilinguìsimu',
	'info_nom_non_utilisateurs_connectes' => 'U vostru nome ùn cumparisce micca in a lista di l’utilizatori cunnessi.',
	'info_nom_utilisateurs_connectes' => 'U vostru nome cumparisce in a lista di l’utilizatori cunnessi.',
	'info_nombre_en_ligne' => 'Attualmente in ligna :',
	'info_non_resultat' => 'Nisunu risultatu per "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'ùn usate micca a messageria interna di stu situ.',
	'info_nouveau_message' => 'AVETE UN NUVELLU MESSAGIU',
	'info_nouveaux_messages' => 'AVETE @total_messages@ NUVELLI MESSAGI',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Hè ubbligatoria st’infurmazione',
	'info_pense_bete' => 'MEMENTU',
	'info_petit_ecran' => 'Pìcculu screnu',
	'info_petition_close' => 'Petizione chjosa',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => 'Parechji segni trovi per "@cherche_mot@":',
	'info_portfolio_automatique' => 'Purtafogliu autumàticu :',
	'info_premier_resultat' => '[@debut_limit@ primi risultati nant’à @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primi risultati nant’à @total@]',
	'info_propose_1' => '[@nom_site_spip@] Prupone : @titre@',
	'info_propose_2' => 'Artìculu prupostu
---------------',
	'info_propose_3' => 'L’artìculu "@titre@" hè prupostu à a pubblicazione.',
	'info_propose_4' => 'Site puru invitatu à vene è cunsultà lu per dà u vostru parè',
	'info_propose_5' => 'in u foru à ellu assuciatu. Hè dispunìbule à l’indirizzu :',
	'info_publie_01' => 'L’article "@titre@" hè statu cunvalidatu da @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBBLICATU : @titre@',
	'info_publie_2' => 'Artìculu pubblicatu
--------------',
	'info_rechercher' => 'Ricircà',
	'info_rechercher_02' => 'Ricircà :',
	'info_remplacer_vignette' => 'Rimpiazzà a figuretta predefinita cù un logo persunalizatu :',
	'info_rubriques_nb' => '@nb@ rùbriche',
	'info_rubriques_un' => '1 rùbrica',
	'info_sans_titre_2' => 'senza tìtulu',
	'info_selectionner_fichier' => 'Pudete sceglie un scedariu da u cartulare @upload@',
	'info_selectionner_fichier_2' => 'Sceglie un schedariu :',
	'info_sites_nb' => '@nb@ siti',
	'info_sites_un' => '1 situ',
	'info_supprimer_vignette' => 'sguassà a figuretta',
	'info_symbole_bleu' => 'U sìmbulu <b>turchinu</b> indetta un <b>mementu</b>: vale à dì un messagiu à usu persunale vostru.',
	'info_symbole_jaune' => 'U sìmbulu <b>giallu</b> indetta un <b>annunciu à tuttu i scrittori</b> : mudifichèvule da tutti l’amministratori, è visìbule da tutti i scrittori.',
	'info_symbole_vert' => 'U sìmbulu <b>verde</b> indetta <b>messagi scambiati cù altri utilizatori</b> di u situ.',
	'info_telecharger_nouveau_logo' => 'Scaricà un nuvellu logo :',
	'info_telecharger_ordinateur' => 'Scaricà da u vostru urdinatore :',
	'info_tous_resultats_enregistres' => '[sò arregistrati tutti i risultati]',
	'info_tout_afficher' => 'Fà cumparisce tuttu',
	'info_travaux_texte' => 'Stu situ ùn hè ancu à cunfigurà. Ripassate più tardi ...',
	'info_travaux_titre' => 'Situ in travagliu',
	'info_trop_resultat' => 'Troppu risultati per "@cherche_mot@" ; Precisate puru a ricerca.',
	'info_utilisation_messagerie_interne' => 'Usate a messageria interna di u situ.',
	'info_valider_lien' => 'cunvalidà sta lea',
	'info_verifier_image' => ', verificate puru ch’elle sò state trasferite cum’ellu ci vole e vostre imàgini.',
	'info_vignette_defaut' => 'Figuretta predefinita',
	'info_vignette_personnalisee' => 'Figuretta persunalizata',
	'info_visite' => 'vìsita :',
	'info_vos_rendez_vous' => 'I vostri appuntamenti in futuru',
	'infos_vos_pense_bete' => 'I vostri mementi', # MODIF

	// L
	'label_poids_fichier' => 'Taglia',
	'lien_afficher_icones_seuls' => 'Fà cumparisce solu l’icone',
	'lien_afficher_texte_icones' => 'Fà cumparisce l’icone cù u testu',
	'lien_afficher_texte_seul' => 'Fà cumparisce solu u testu',
	'lien_liberer' => 'liberà',
	'lien_liberer_tous' => 'liberà st’artìculi', # MODIF
	'lien_nouvea_pense_bete' => 'NUVELLU MEMENTU',
	'lien_nouveau_message' => 'NUVELLU MESSAGIU',
	'lien_nouvelle_annonce' => 'NUVELLU ANNUNCIU',
	'lien_petitions' => 'PETIZIONE',
	'lien_popularite' => 'pupularità : @popularite@%',
	'lien_racine_site' => 'RÀDICA DI U SITU',
	'lien_reessayer' => 'pruvà torna',
	'lien_repondre_message' => 'Risponde à stu messagiu',
	'lien_supprimer' => 'sguassà',
	'lien_tout_afficher' => 'Fà cumparisce tuttu',
	'lien_visite_site' => 'visità stu situ',
	'lien_visites' => '@visites@ vìsite',
	'lien_voir_auteur' => 'Vede st’autore',
	'ligne' => 'Ligna',
	'login' => 'Cunnessione',
	'login_acces_prive' => 'accessu à u spaziu privatu',
	'login_autre_identifiant' => 'cunnette si cù un altru còdice',
	'login_cookie_accepte' => 'Parametrate puru u vostru navigatore di manera ch’ellu l’accetti (omancu per u situ).',
	'login_cookie_oblige' => 'Duvite accettà i cookies da pudè identificà vi di modu sicuru nant’à stu situ.',
	'login_deconnexion_ok' => 'Scunnessione compia.',
	'login_erreur_pass' => 'Errore di password.',
	'login_espace_prive' => 'spaziu privatu',
	'login_identifiant_inconnu' => 'Hè scunnisciutu u còdice « @login@ ».',
	'login_login' => 'Login :',
	'login_login2' => 'Login (còdice di cunnessione à u situ) :', # MODIF
	'login_login_pass_incorrect' => '(Login o password sbagliatu.)',
	'login_motpasseoublie' => 'password dimenticatu ?',
	'login_non_securise' => 'Attenti, stu furmulariu ùn hè micca sicurizatu.
			Sè vo ùn vulete chì u vostru password possi esse chjappu nant’à a rete, attivate puru Javascript
			in u vostru navigatore è',
	'login_nouvelle_tentative' => 'Nuvella Prova',
	'login_par_ici' => 'Site arregistratu ... per quindi ...',
	'login_pass2' => 'Password :',
	'login_preferez_refuser' => '<b>Sè vo preferite rifiutà i cookies</b>, v’hè dispostu un altru mètudu di cunnessione (sicurizata di menu) :',
	'login_recharger' => 'ricaricà sta pàgina',
	'login_rester_identifie' => 'Firmà cunnessi qualchì ghjornu',
	'login_retour_public' => 'Ritornu à u situ pùbblicu',
	'login_retour_site' => 'Ritornu à u situ pùbblicu',
	'login_retoursitepublic' => 'ritornu à u situ pùbblicu',
	'login_sinscrire' => 'iscrive si',
	'login_test_navigateur' => 'prova navigatore/ricunnessione',
	'login_verifiez_navigateur' => '(Verificate quantunque chì u vostru navigatore ùn abbia memurizatu u vostru password...)',

	// M
	'masquer_colonne' => 'Piattà sta culonna',
	'masquer_trad' => 'piattà e traduzzioni',
	'module_fichiers_langues' => 'Schedari di lingua',

	// N
	'navigateur_pas_redirige' => 'S’ellu ùn hè rindirizzatu u vostru navigatore, cliccate puru quì per cuntinuà.',
	'numero' => 'Nùmeru',

	// O
	'occurence' => 'Occurenza',
	'onglet_affacer_base' => 'Sguassà a basa',
	'onglet_auteur' => 'L’autore',
	'onglet_contenu_site' => 'Cuntenutu di u situ',
	'onglet_evolution_visite_mod' => 'Evuluzione',
	'onglet_fonctions_avances' => 'Funzioni avanzate',
	'onglet_informations_personnelles' => 'Infurmazioni persunali',
	'onglet_interactivite' => 'Interattività',
	'onglet_messagerie' => 'Messageria',
	'onglet_repartition_rubrique' => 'Scumpartimentu per rùbbriche',
	'onglet_save_restaur_base' => 'Salvà/risturà a basa',
	'onglet_vider_cache' => 'Sviutà u cache',

	// P
	'pass_choix_pass' => 'Sceglite puru u vostru password :',
	'pass_erreur' => 'Errore',
	'pass_erreur_acces_refuse' => '<b>Errore :</b> ùn avete più accessu à stu situ.',
	'pass_erreur_code_inconnu' => '<b>Errore :</b> stu còdice ùn currisponde à nisun utilizatore chì abbia acessu à stu situ.',
	'pass_erreur_non_enregistre' => '<b>Errore :</b> l’indirizzu <tt>@email_oubli@</tt> ùn hè micca arregistrata in stu situ.',
	'pass_erreur_non_valide' => '<b>Errore :</b> st’email <tt>@email_oubli@</tt> ùn hè micca vàlidu !',
	'pass_erreur_probleme_technique' => '<b>Errore :</b> per via d’un prublemu tècnicu, ùn pò micca esse mandatu l’email.',
	'pass_espace_prive_bla' => 'U spaziu privatu di stu situ hè apertu à i visitori, dopu iscritti. Arregistratu chè vo serete, 
		puderete puru cunsultà l’artìculi in corsu di scrittura, prupone artìculi è participà à tutti i fori.',
	'pass_forum_bla' => 'Avete dumandatu à intervene nant’à un foru riservatu à i visitori arregistrati.',
	'pass_indiquez_cidessous' => 'Rinsignate puru quì sottu l’indirizzu email cun chì erate digià arregistratu. Riceverete un email 
			spieghendu vi cumu fà pè ricuarà u vostru accessu.',
	'pass_mail_passcookie' => '(què hè un messagiu autumàticu)
Pè ricuarà u vostru accessu à u situ
@nom_site_spip@ (@adresse_site@)

Andate puru à l’indirizzu  :

    @sendcookie@

Puderete tandu inserisce un nuvellu password 
è cusì cunnette vi torna à u situ.

',
	'pass_mot_oublie' => 'Password dimenticatu',
	'pass_nouveau_enregistre' => 'Hè statu arregistratu u vostru password.',
	'pass_nouveau_pass' => 'Nuvellu password',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Password dimenticatu',
	'pass_quitter_fenetre' => 'Esce da sta finestra',
	'pass_rappel_login' => 'Attenti : u vostru còdice (login) hè « @login@ ».',
	'pass_recevoir_mail' => 'Avete da riceve un email spieghendu vi cumu ricuarà u vostru accessu à u situ.',
	'pass_retour_public' => 'Ritornu à u situ pùbblicu',
	'pass_rien_a_faire_ici' => 'Nunda à fà quì.',
	'pass_vousinscrire' => 'Iscrive vi nant’à u situ',
	'precedent' => 'precedente',
	'previsualisation' => 'Vista in antìcipu',
	'previsualiser' => 'Vede in antìcipu',

	// R
	'retour' => 'Ritornu',

	// S
	'spip_conforme_dtd' => 'SPIP ghjudicheghja stu ducumentu cunforme à u so DOCTYPE :',
	'squelette' => 'Mudellu',
	'squelette_inclus_ligne' => 'mudellu inclusu, ligna',
	'squelette_ligne' => 'mudelle, ligna',
	'stats_visites_et_popularite' => '@visites@ vìsite ; pupularità : @popularite@',
	'suivant' => 'In davanti',

	// T
	'taille_ko' => '@taille@ ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ oct',
	'texte_actualite_site_1' => 'Quand’è vo serete pù pràticu cù l’interfaccia, puderete cliccà nant’à «',
	'texte_actualite_site_2' => 'interfaccia sana',
	'texte_actualite_site_3' => '» pè pudè apre di più pussibulità.',
	'texte_creation_automatique_vignette' => 'Hè attivata nant’à u situ a creazione di figurette pè a vista in antìcipu. 
				Sè vo stallate imàgini di furmatu/i @gd_formats@ usendu stu furmulariu, 
				seranu accumpagnate da una figuretta d’una taglia màsima di @taille_preview@ pixels.',
	'texte_documents_associes' => 'I seguenti ducumenti sò assuciati à l’artìculu,
				ma ùn sò micca stati direttamente inseriti.
				Secondu cum’ella hè definita a paginatura di u situ pùbblicu,
				puderanu cumparisce cum’è ducumenti alleati.',
	'texte_erreur_mise_niveau_base' => 'Errore di basa di dati durante a messa à livellu.
		L’imàgine <b>@fichier@</b> ùn hè passata (artìculu @id_article@).
		Tenite bè à mente sta riferenza, pruvate torna a messa à livellu, è infine verificate chì l’imàgini
		cumpariscanu sempre in l’artìculi.',
	'texte_erreur_visiteur' => 'Avete pruvatu d’accede à u spaziu privatu cù un login chì ùn a permette micca.',
	'texte_inc_auth_1' => 'Site identificatu cù u login <b>@auth_login@</b>, ma questu ùn esiste micca/più in a basa.
		Pruvate à',
	'texte_inc_auth_2' => 'cunnette vi torna',
	'texte_inc_auth_3' => ', dopu esse esciutu; poi aprite torna u navigatore.',
	'texte_inc_config' => 'E mudìfiche fatte in ste pàgine pesanu assai nant’à u funziunamentu di u vostru situ. 
  Vi cunsigliemu d’ùn fà ci interventi fintantu chì ùn serete abbastanza pràticu cù u funziunamentu di u sistema SPIP. <br /><br />
  <b>sia cum’ella sia, hè arricumandatu assai di lascià a gestione di ste pàgine à u webmaestru di u vostru situ.</b>',
	'texte_inc_meta_1' => 'U sistema hà scontru un errore mentre a scrittura di u schedariu <code>@fichier@</code>. 
			Intantu chè amministratore di u situ,',
	'texte_inc_meta_2' => 'verificate puru i diritti di scrittura',
	'texte_inc_meta_3' => 'nant’à u cartulare <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'in corsu di scrittura',
	'texte_statut_poubelle' => 'à a rumènzula',
	'texte_statut_propose_evaluation' => 'prupostu à a valutazione',
	'texte_statut_publie' => 'pubblicatu in ligna',
	'texte_statut_refuse' => 'rifiutatu',
	'titre_ajouter_mot_cle' => 'AGHJUNGHJE UN SEGNU :',
	'titre_cadre_raccourcis' => 'ACCURTATOGHJI :',
	'titre_changer_couleur_interface' => 'Scambià u culore di l’interfaccia',
	'titre_image_admin_article' => 'Pudete amministrà st’artìculu',
	'titre_image_administrateur' => 'Amministratore',
	'titre_image_aide' => 'Aiutu nant’à st’elementu',
	'titre_image_auteur_supprime' => 'Autore sguassatu',
	'titre_image_redacteur' => 'Scrittore senza accessu',
	'titre_image_redacteur_02' => 'Scrittore',
	'titre_image_visiteur' => 'Visitore',
	'titre_joindre_document' => 'ALLEà UN DUCUMENTU',
	'titre_mots_cles' => 'SEGNI',
	'titre_probleme_technique' => 'Attenti : un prublemu tècnicu (servore SQL) impedisce l’accessu à sta parte di u situ.',
	'titre_publier_document' => 'PUBBLICà UN DUCUMENTU IN STA RÙBBRICA',
	'titre_signatures_attente' => 'Zifre in attesa di cunvalidazione',
	'titre_signatures_confirmees' => 'Zifre cunfirmate',
	'titre_statistiques' => 'Statìstiche di u situ',
	'titre_titre_document' => 'Tìtulu di u ducumentu :',
	'todo' => 'In futuru',
	'trad_reference' => '(artìculu di riferenza)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' : balisa B più in dà',
	'zbug_balise_inexistante' => 'errore @from@: a balisa #@balise@ ùn esiste micca',
	'zbug_balise_sans_argument' => 'Ci manca l’argumentu in a balisa @balise@',
	'zbug_boucle' => 'cìculu',
	'zbug_boucle_recursive_undef' => 'cìculu ricursivu indefinitu',
	'zbug_calcul' => 'càlculu',
	'zbug_champ_hors_boucle' => 'Campu @champ@ hors boucle',
	'zbug_champ_hors_motif' => 'Campu @champ@ hors d’une boucle de motif @motif@',
	'zbug_code' => 'còdice',
	'zbug_critere_inconnu' => 'criteriu scunnisciutu @critere@',
	'zbug_distant_interdit' => 'esternu interdettu', # Contexte : une base de données "externe", pas gérée par SPIP, mais que SPIP 1.8 sait utiliser dans ses boucles -- seul problèmes certaines manipulations sont interdites sur ces bases-là.
	'zbug_doublon_table_sans_cle_primaire' => 'duppioni in una tàvula senza chjave primaria atòmica',
	'zbug_doublon_table_sans_index' => 'duppioni in un tàvula senza ìndice',
	'zbug_erreur_boucle_double' => 'CìCULU@id@: doppia definizione',
	'zbug_erreur_boucle_fermant' => 'CìCULU@id@: ci manca u tag di chjusura',
	'zbug_erreur_boucle_syntaxe' => 'Sintassa di cìculu sbagliata',
	'zbug_erreur_compilation' => 'Errore di cumpilazione',
	'zbug_erreur_execution_page' => 'errore d’eseguimentu di a pàgina',
	'zbug_erreur_filtre' => 'Errore : stacciu <b>« @filtre@ »</b> indefinitu',
	'zbug_erreur_meme_parent' => '{meme_parent} pò esse appiecatu solu à i cìculi (FORI) o (RùBBRICHE)',
	'zbug_erreur_squelette' => 'Errore/i in u mudellu',
	'zbug_hors_compilation' => 'Fora di cumpilazione',
	'zbug_info_erreur_squelette' => 'Errore nant’à u situ',
	'zbug_inversion_ordre_inexistant' => 'inversione d’un òrdine inesistente',
	'zbug_pagination_sans_critere' => '#PAGINATION senza criteriu {pagination} o puru impiegatu in un cìculu ricursivu',
	'zbug_parametres_inclus_incorrects' => 'Paràmetri d’inclusione sbagliati',
	'zbug_profile' => 'Tempu di càlculu : @time@',
	'zbug_resultat' => 'risultatu',
	'zbug_serveur_indefini' => 'servore SQL indefinitu',
	'zbug_statistiques' => 'Statìstiche di e richieste SQL in òrdine di durata',
	'zbug_table_inconnue' => 'Tàvula SQL « @table@ » scunnisciuta',
	'zxml_connus_attributs' => 'attributi cunnisciuti',
	'zxml_de' => 'di',
	'zxml_inconnu_attribut' => 'attributu scunnisciutu',
	'zxml_inconnu_balise' => 'balisa scunnisciuta',
	'zxml_inconnu_entite' => 'entità scunnisciuta',
	'zxml_inconnu_id' => 'ID scunnisciutu',
	'zxml_mais_de' => 'ma di',
	'zxml_non_conforme' => 'ùn hè cunforme à u mutivu',
	'zxml_non_fils' => 'ùn hè figliolu di',
	'zxml_nonvide_balise' => 'balisa micca viota',
	'zxml_obligatoire_attribut' => 'attributu ubbligatoriu ma inesistente in',
	'zxml_succession_fils_incorrecte' => 'eredità di i figlioli sbagliata',
	'zxml_survoler' => 'passà sopra cù u topu pè vede quelli curretti',
	'zxml_valeur_attribut' => 'valore di l’attributu',
	'zxml_vide_balise' => 'balisa viota',
	'zxml_vu' => 'vistu prima'
);

?>
